@@ -5,7 +5,7 @@ function(genos,subset,mat=NULL,power=10){
   n.genos<-ncol(genos)
   #Make and transform kinship matrix
   if(is.null(mat)){
-    mat<-A.mat(t(genos))
+    mat<-Mat(genos)
   }
   mat.adj<-(2*(mat-min(mat))/(max(mat)-min(mat)))^power
   for(i in 1:n.genos){
