@@ -4,7 +4,7 @@ function(genos,subset,power=10){
   mode(genos)<-"numeric"
   genos[genos==0]<-NA
   n.genos<-ncol(genos)
-  mat<-A.mat(t(genos))
+  mat<-Mat(genos)
   mat<-(2*(mat-min(mat))/(max(mat)-min(mat)))^power
   for(i in 1:n.genos){
     mat[i,i]<-0
